@@ -174,7 +174,7 @@ def plot_viterbi_paths(hmm, spikes, time=None, colors=None, axes=None, legend=Tr
 
 
     BIC = hmm.BIC
-    paths = hmm.best_sequences
+    paths = hmm.stat_arrays['best_sequences']
     n_trials, n_steps = paths.shape
     n_states = hmm.n_states
     if time is None:
@@ -192,8 +192,8 @@ def plot_viterbi_paths(hmm, spikes, time=None, colors=None, axes=None, legend=Tr
                 handles.append(h)
                 labels.append(l)
 
-    if time[0] != 0:
-        ax.axvline(0, color='red', linestyle='--', linewidth=3, alpha=0.8)
+        if time[0] != 0:
+            ax.axvline(0, color='red', linestyle='--', linewidth=3, alpha=0.8)
 
     if legend:
         mid = int(n_trials/2)
@@ -261,7 +261,7 @@ def plot_forward_probs(hmm, spikes, dt, time=None, colors=None, axes=None, legen
     if legend:
         fig.subplots_adjust(right=0.9)  # To  make room for legend
 
-    alphas = hmm.get_forward_probabilities(spikes, dt)
+    alphas, norms = hmm.get_forward_probabilities(spikes, dt)
     n_trials, n_states, n_steps = alphas.shape
     if time is None:
         time = np.arange(0, n_steps)
@@ -353,7 +353,7 @@ def plot_backward_probs(hmm, spikes, dt, time=None, colors=None, axes=None, lege
         return fig, axes
 
 
-def plot_gamma_probs(hmm, spikes, dt, time=None, colors=None, axes=None, legend=True,
+def plot_gamma_probs(hmm, spikes=None, dt=None, time=None, colors=None, axes=None, legend=True,
                      hmm_id=None, thresh=0.75, save_file=None):
     if not axes:
         fig, axes = make_hmm_raster(spikes, time=time)
@@ -363,7 +363,13 @@ def plot_gamma_probs(hmm, spikes, dt, time=None, colors=None, axes=None, legend=
     if legend:
         fig.subplots_adjust(right=0.9)  # To  make room for legend
 
-    gammas = hmm.get_gamma_probabilities(spikes, dt)
+    gammas = hmm.stat_arrays['gamma_probabilities']
+    if gammas == []:
+        if spikes is None and dt is None:
+            raise ValueError('Not enough info to compute gamma probabilities')
+
+        gammas = hmm.get_gamma_probabilities(spikes, dt)
+
     n_trials, n_states, n_steps = gammas.shape
     if time is None:
         time = np.arange(0, n_steps)
@@ -425,6 +431,7 @@ def plot_hmm_rates(rates, axes=None, colors=None):
     df = pd.DataFrame(rates, columns=['state %i' % i for i in range(n_states)])
     df['cell'] = ['cell %i' % i for i in df.index]
     df = pd.melt(df, 'cell', ['state %i' % i for i in range(n_states)], 'state', 'rate')
+    x_max = 0
     for g, ax, col in zip(df.groupby('state'), axes, colors):
         sns.barplot(data=g[1], x='rate', y='cell',
                     color='black', ax=ax)
@@ -435,10 +442,17 @@ def plot_hmm_rates(rates, axes=None, colors=None):
         ax.patch.set_alpha(0.5)
         ax.set_yticklabels([])
         ax.tick_params(left=False)
+        xl = ax.get_xlim()
+        if xl[1] > x_max:
+            x_max = xl[1]
+
         for spine in ax.spines.values():
             spine.set_visible(False)
 
 
+    for ax in axes:
+        ax.set_xlim([0, x_max])
+
     axes[0].set_yticklabels(['Cell %i' % i for i in range(n_cells)])
     mid = int(n_states/2)
     axes[mid].set_xlabel('Firing Rate (Hz)')
